@@ -121,6 +121,7 @@ class Application(Gtk.Application):
         """
             Init main application
         """
+        self.fixed_775600 = Lio.check_fix_775600()
         self.__is_fs = False
         if Gtk.get_minor_version() > 18:
             cssProviderFile = Lio.File.new_for_uri(
@@ -249,6 +250,8 @@ class Application(Gtk.Application):
                 except Exception as e:
                     print("Application::prepare_to_exit()", e)
             dump(track_id, open(DataPath + "/track_id.bin", "wb"))
+            dump([self.player.is_playing, self.player.is_party],
+                 open(DataPath + "/player.bin", "wb"))
             # Save current playlist
             if self.player.current_track.id == Type.RADIOS:
                 playlist_ids = [Type.RADIOS]
@@ -266,7 +269,8 @@ class Application(Gtk.Application):
         self.player.stop_all()
         if self.window:
             self.window.stop_all()
-        self.charts.stop()
+        if self.charts is not None:
+            self.charts.stop()
         self.quit()
 
     def quit(self):
