@@ -176,13 +176,14 @@ class AlbumArt(BaseArt, TagReader):
                                                                        size,
                                                                        ratio,
                                                                        None)
+                        stream.close()
                 # Use tags artwork
                 if pixbuf is None and album.tracks:
                     try:
                         pixbuf = self.pixbuf_from_tags(
                                     album.tracks[0].uri, size)
                     except Exception as e:
-                        pass
+                        print("AlbumArt::get_album_artwork()", e)
 
                 # Use folder artwork
                 if pixbuf is None and album.uri != "":
@@ -200,6 +201,7 @@ class AlbumArt(BaseArt, TagReader):
                                                                        size,
                                                                        ratio,
                                                                        None)
+                        stream.close()
                 # Use default artwork
                 if pixbuf is None:
                     self.cache_album_art(album.id)
@@ -207,7 +209,9 @@ class AlbumArt(BaseArt, TagReader):
                                                  size,
                                                  scale)
                 else:
-                    pixbuf.savev(cache_path_jpg, "jpeg", ["quality"], ["90"])
+                    pixbuf.savev(cache_path_jpg, "jpeg", ["quality"],
+                                 [str(Lp().settings.get_value(
+                                                'cover-quality').get_int32())])
             surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, scale, None)
             del pixbuf
             return surface
@@ -292,7 +296,10 @@ class AlbumArt(BaseArt, TagReader):
                                                                ArtSize.MONSTER,
                                                                True,
                                                                None)
-                pixbuf.savev(store_path, "jpeg", ["quality"], ["90"])
+                stream.close()
+                pixbuf.savev(store_path, "jpeg", ["quality"],
+                             [str(Lp().settings.get_value(
+                                                'cover-quality').get_int32())])
                 dst = Lio.File.new_for_uri(arturi)
                 src = Lio.File.new_for_path(store_path)
                 src.move(dst, Gio.FileCopyFlags.OVERWRITE, None, None)
@@ -399,6 +406,7 @@ class AlbumArt(BaseArt, TagReader):
                                                                    size,
                                                                    False,
                                                                    None)
+                stream.close()
         except Exception as e:
             print("AlbumArt::pixbuf_from_tags():", e)
         return pixbuf
@@ -429,8 +437,10 @@ class AlbumArt(BaseArt, TagReader):
                                                            ArtSize.MONSTER,
                                                            True,
                                                            None)
+        stream.close()
         pixbuf.savev("%s/lollypop_cover_tags.jpg" % self._CACHE_PATH,
-                     "jpeg", ["quality"], ["90"])
+                     "jpeg", ["quality"], [str(Lp().settings.get_value(
+                                           'cover-quality').get_int32())])
         del pixbuf
         f = Lio.File.new_for_path("%s/lollypop_cover_tags.jpg" %
                                   self._CACHE_PATH)
