@@ -26,6 +26,8 @@ class ArtworkSearch(Gtk.Bin):
         Search for artwork
     """
 
+    # FIXME: Missing Gio.Cancellable()
+
     def __init__(self, artist_id, album):
         """
             Init search
@@ -74,6 +76,8 @@ class ArtworkSearch(Gtk.Bin):
         self._stack.add_named(builder.get_object('scrolled'), 'main')
         self._stack.set_visible_child_name('main')
         self.add(widget)
+        self._api_entry.set_text(
+                            Lp().settings.get_value('cs-api-key').get_string())
         self.set_size_request(700, 400)
 
     def populate(self):
@@ -85,6 +89,7 @@ class ArtworkSearch(Gtk.Bin):
                                             ArtSize.BIG,
                                             self.get_scale_factor())
         image.set_from_surface(surface)
+        del surface
         image.set_property('valign', Gtk.Align.CENTER)
         image.set_property('halign', Gtk.Align.CENTER)
         image.get_style_context().add_class('cover-frame')
@@ -101,7 +106,7 @@ class ArtworkSearch(Gtk.Bin):
                     self.__add_pixbuf(data)
                 except Exception as e:
                     print("ArtworkSearch::populate()", e)
-        # Then duckduckgo
+        # Then google
         self.__loading = True
         t = Thread(target=self.__populate)
         t.daemon = True
@@ -205,43 +210,48 @@ class ArtworkSearch(Gtk.Bin):
 #######################
 # PRIVATE             #
 #######################
-    def __populate(self, search=""):
+    def __get_current_searches(self):
+        """
+            Return current searches
+            @return [str]
+        """
+        searches = []
+        if self._entry.get_text() != "":
+            searches = [self._entry.get_text()]
+        elif self.__album is not None:
+            searches = ["%s+%s" % (self.__artist, self.__album.name)]
+        elif self.__artist_id is not None:
+            for album_id in Lp().artists.get_albums([self.__artist_id]):
+                for genre_id in Lp().albums.get_genre_ids(album_id):
+                    genre = Lp().genres.get_name(genre_id)
+                    searches.append("%s+%s" % (self.__artist, genre))
+            searches.append(self.__artist)
+        return searches
+
+    def __populate(self, current_search=""):
         """
             Same as populate
-            @param search as str
+            @param current search as str
             @thread safe
         """
         urls = []
         if get_network_available():
-            if search != "":
-                urls = Lp().art.get_google_arts(search)
-            elif self.__album is not None:
-                urls = Lp().art.get_google_arts("%s+%s" % (
-                                               self.__artist,
-                                               self.__album.name))
-            elif self.__artist_id is not None:
-                for album_id in Lp().artists.get_albums([self.__artist_id]):
-                    for genre_id in Lp().albums.get_genre_ids(album_id):
-                        genre = Lp().genres.get_name(genre_id)
-                        urls += Lp().art.get_google_arts("%s+%s" % (
-                                                                 self.__artist,
-                                                                 genre))
-                urls += Lp().art.get_google_arts(self.__artist)
+            for search in self.__get_current_searches():
+                urls += Lp().art.get_google_arts(search)
             if urls:
-                self.__add_pixbufs(urls, search)
+                self.__add_pixbufs(urls, current_search)
             else:
-                GLib.idle_add(self.__show_not_found)
+                self.__fallback(current_search)
         else:
             GLib.idle_add(self._spinner.stop)
 
-    def __add_pixbufs(self, urls, search):
+    def __add_pixbufs(self, urls, current_search):
         """
             Add urls to the view
             @param urls as [string]
-            @param search as str
-            @param duck api start as int
+            @param current search as str
         """
-        if search != self._entry.get_text():
+        if current_search != self._entry.get_text():
             return
         if urls and self.__loading:
             url = urls.pop(0)
@@ -253,18 +263,40 @@ class ArtworkSearch(Gtk.Bin):
             except Exception as e:
                 print("ArtworkSearch::__add_pixbufs: %s" % e)
             if self.__loading:
-                self.__add_pixbufs(urls, search)
+                self.__add_pixbufs(urls, current_search)
         else:
             self._spinner.stop()
 
-    def __show_not_found(self):
+    def __fallback(self, current_search):
         """
-            Show not found message
+            Fallback google image search, low quality
+            @param current search as str
         """
-        self._popover.show()
-        self._api_entry.set_text(
-                            Lp().settings.get_value('cs-api-key').get_string())
-        self._spinner.stop()
+        try:
+            from bs4 import BeautifulSoup
+        except:
+            print("$ sudo pip3 install beautifulsoup4")
+            return
+        urls = []
+        GLib.idle_add(self._label.set_text,
+                      _("Low quality, missing API key..."))
+        try:
+            for search in self.__get_current_searches():
+                url = "https://www.google.fr/search?q=%s&tbm=isch" %\
+                    Lio.uri_escape_string(search, None, True)
+                f = Lio.File.new_for_uri(url)
+                (status, data, tag) = f.load_contents()
+                if status:
+                    html = data.decode('utf-8')
+                    soup = BeautifulSoup(html, 'html.parser')
+                    for link in soup.findAll('img'):
+                        try:
+                            urls.append(link.attrs['data-src'])
+                        except:
+                            pass
+        except Exception as e:
+            print("ArtworkSearch::__fallback: %s" % e)
+        self.__add_pixbufs(urls, current_search)
 
     def __add_pixbuf(self, data):
         """
@@ -279,6 +311,7 @@ class ArtworkSearch(Gtk.Bin):
                     ArtSize.MONSTER,
                     True,
                     None)
+                stream.close()
             stream = Gio.MemoryInputStream.new_from_data(data, None)
             if stream is not None:
                 big = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
@@ -286,6 +319,7 @@ class ArtworkSearch(Gtk.Bin):
                     ArtSize.BIG,
                     True,
                     None)
+                stream.close()
             image = Gtk.Image()
             image.get_style_context().add_class('cover-frame')
             image.set_property('halign', Gtk.Align.CENTER)
