@@ -63,8 +63,6 @@ class CollectionScanner(GObject.GObject, TagReader):
             Lp().window.progress.add(self)
             Lp().window.progress.set_fraction(0.0, self)
 
-            if Lp().notify is not None:
-                Lp().notify.send(_("Your music is updating"))
             self.__thread = Thread(target=self.__scan, args=(uris,))
             self.__thread.daemon = True
             self.__thread.start()
@@ -359,7 +357,6 @@ class CollectionScanner(GObject.GObject, TagReader):
         uri = Lp().tracks.get_uri(track_id)
         self.__history.add(name, duration, popularity, rate,
                            ltime, mtime, loved, album_popularity, album_rate)
-        Lp().playlists.remove(uri)
         Lp().tracks.remove(track_id)
         Lp().tracks.clean(track_id)
         deleted = Lp().albums.clean(album_id)
