@@ -32,7 +32,7 @@ class TracksDatabase:
         pass
 
     def add(self, name, uri, duration, tracknumber, discnumber, discname,
-            album_id, year, popularity, ltime, mtime, persistent=1):
+            album_id, year, popularity, rate, ltime, mtime, persistent=1):
         """
             Add a new track to database
             @param name as string
@@ -45,6 +45,7 @@ class TracksDatabase:
             @param genre_id as int
             @param year as int
             @param popularity as int
+            @param rate as int
             @param ltime as int
             @param mtime as int
             @param persistent as int
@@ -55,8 +56,9 @@ class TracksDatabase:
             result = sql.execute(
                 "INSERT INTO tracks (name, uri, duration, tracknumber,\
                 discnumber, discname, album_id,\
-                year, popularity, ltime, mtime, persistent) VALUES\
-                (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", (name,
+                year, popularity, rate, ltime, mtime, persistent) VALUES\
+                (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", (
+                                                        name,
                                                         uri,
                                                         duration,
                                                         tracknumber,
@@ -65,6 +67,7 @@ class TracksDatabase:
                                                         album_id,
                                                         year,
                                                         popularity,
+                                                        rate,
                                                         ltime,
                                                         mtime,
                                                         persistent))
@@ -202,6 +205,20 @@ class TracksDatabase:
                 return str(v[0])
             return ""
 
+    def get_rate(self, track_id):
+        """
+            Get track rate
+            @param track id as int
+            @return rate as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT rate FROM tracks WHERE rowid=?",
+                                 (track_id,))
+            v = result.fetchone()
+            if v and v[0]:
+                return v[0]
+            return Type.NONE
+
     def get_uri(self, track_id):
         """
             Get track uri for track id
@@ -229,6 +246,18 @@ class TracksDatabase:
             sql.commit()
             Lp().tracks.set_mtime(track_id, 0)
 
+    def set_rate(self, track_id, rate):
+        """
+            Set track rate
+            @param Track id as int
+            @param rate as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("UPDATE tracks SET rate=?\
+                         WHERE rowid=?",
+                        (rate, track_id))
+            sql.commit()
+
     def get_album_id(self, track_id):
         """
             Get album id for track id
@@ -412,15 +441,30 @@ class TracksDatabase:
                                  (artist_id, Type.CHARTS))
             return list(result)
 
-    def get_populars(self):
+    def get_rated(self, limit=100):
         """
-            Return most listened to tracks
+            Return tracks with rate >= 4
+            @param limit as int
+            @return tracks as [int]
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT rowid FROM tracks\
+                                  WHERE rate >= 4\
+                                  ORDER BY popularity DESC LIMIT ?",
+                                 (limit,))
+            return list(itertools.chain(*result))
+
+    def get_populars(self, limit=100):
+        """
+            Return populars tracks
+            @param limit as int
             @return tracks as [int]
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT rowid FROM tracks\
                                   WHERE popularity!=0\
-                                  ORDER BY popularity DESC LIMIT 100")
+                                  ORDER BY popularity DESC LIMIT ?",
+                                 (limit,))
             return list(itertools.chain(*result))
 
     def get_avg_popularity(self):
