@@ -29,8 +29,11 @@ class Playlists(GObject.GObject):
     """
         Playlists manager
     """
-    _LOCAL_PATH = GLib.get_home_dir() + "/.local/share/lollypop"
-    _DB_PATH = "%s/playlists.db" % _LOCAL_PATH
+    if GLib.getenv("XDG_DATA_HOME") is None:
+        __LOCAL_PATH = GLib.get_home_dir() + "/.local/share/lollypop"
+    else:
+        __LOCAL_PATH = GLib.getenv("XDG_DATA_HOME") + "/lollypop"
+    _DB_PATH = "%s/playlists.db" % __LOCAL_PATH
     __gsignals__ = {
         # Add or remove a playlist
         'playlists-changed': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
@@ -187,6 +190,29 @@ class Playlists(GObject.GObject):
                                  (playlist_id,))
             return list(itertools.chain(*result))
 
+    def get_track_ids_sorted(self, playlist_id):
+        """
+            Return availables track ids for playlist sorted by artist/album
+            If playlist name == Type.ALL, then return all tracks from db
+            @param playlist id as int
+            @return array of track id as int
+        """
+        with SqlCursor(self) as sql:
+            result = sql.execute("SELECT music.tracks.rowid\
+                                  FROM tracks, music.tracks,\
+                                  music.track_artists, music.artists\
+                                  WHERE tracks.playlist_id=?\
+                                  AND music.track_artists.track_id=\
+                                  music.tracks.rowid\
+                                  AND music.artists.id=\
+                                  music.track_artists.artist_id\
+                                  AND music.tracks.uri=\
+                                  main.tracks.uri\
+                                  ORDER BY\
+                                  music.artists.sortname, album_id",
+                                 (playlist_id,))
+            return list(itertools.chain(*result))
+
     def get_id(self, playlist_name):
         """
             Get playlist id
