@@ -263,31 +263,111 @@ class TagReader(Discoverer):
             year = None
         return year
 
+    def get_original_year(self, tags):
+        """
+            Return original release year
+            @param tags as Gst.TagList
+            @return year as int or None
+        """
+        def get_id3():
+            try:
+                size = tags.get_tag_size('private-id3v2-frame')
+                for i in range(0, size):
+                    (exists, sample) = tags.get_sample_index(
+                                                         'private-id3v2-frame',
+                                                         i)
+                    if not exists:
+                        continue
+                    (exists, m) = sample.get_buffer().map(Gst.MapFlags.READ)
+                    if not exists:
+                        continue
+                    string = m.data.decode('utf-8')
+                    if string.startswith('TDOR'):
+                        split = string.split('\x00')
+                        return int(split[-1][:4])
+            except:
+                pass
+            return None
+
+        def get_ogg():
+            try:
+                size = tags.get_tag_size('extended-comment')
+                for i in range(0, size):
+                    (exists, sample) = tags.get_string_index(
+                                                         'extended-comment',
+                                                         i)
+                    if not exists or not sample.startswith("ORIGINALDATE="):
+                        continue
+                    # ORIGINALDATE=1999-03-10 => Only year
+                    return int(sample[13:][:4])
+            except:
+                pass
+            return None
+
+        if tags is None:
+            return None
+        year = get_id3()
+        if year is None:
+            year = get_ogg()
+        return year
+
     def get_lyrics(self, tags):
         """
             Return lyrics for tags
             @parma tags as Gst.TagList
             @return lyrics as str
         """
+        def get_mp4():
+            try:
+                (exists, sample) = tags.get_string_index('lyrics', 0)
+                if exists:
+                    return sample
+            except:
+                pass
+            return ""
+
+        def get_id3():
+            try:
+                size = tags.get_tag_size('private-id3v2-frame')
+                for i in range(0, size):
+                    (exists, sample) = tags.get_sample_index(
+                                                         'private-id3v2-frame',
+                                                         i)
+                    if not exists:
+                        continue
+                    (exists, m) = sample.get_buffer().map(Gst.MapFlags.READ)
+                    if not exists:
+                        continue
+                    string = m.data.decode('utf-8')
+                    if string.startswith('USLT'):
+                        split = string.split('\x00')
+                        return split[-1:][0]
+            except:
+                pass
+            return ""
+
+        def get_ogg():
+            try:
+                size = tags.get_tag_size('extended-comment')
+                for i in range(0, size):
+                    (exists, sample) = tags.get_string_index(
+                                                         'extended-comment',
+                                                         i)
+                    if not exists or not sample.startswith("LYRICS="):
+                        continue
+                    return sample[7:]
+            except:
+                pass
+            return ""
+
         if tags is None:
             return ""
-        try:
-            size = tags.get_tag_size('private-id3v2-frame')
-            for i in range(0, size):
-                (exists, sample) = tags.get_sample_index('private-id3v2-frame',
-                                                         i)
-                if not exists:
-                    continue
-                (exists, m) = sample.get_buffer().map(Gst.MapFlags.READ)
-                if not exists:
-                    continue
-                string = m.data.decode('utf-8')
-                if string.startswith('USLT'):
-                    split = string.split('\x00')
-                    return split[-1:][0]
-        except:
-            pass
-        return ""
+        lyrics = get_mp4()
+        if not lyrics:
+            lyrics = get_id3()
+        if not lyrics:
+            lyrics = get_ogg()
+        return lyrics
 
     def add_artists(self, artists, album_artists, sortnames):
         """
@@ -372,14 +452,16 @@ class TagReader(Discoverer):
         return genre_ids
 
     def add_album(self, album_name, artist_ids,
-                  uri, popularity, mtime, remote):
+                  uri, loved, popularity, rate, mtime, remote):
         """
             Add album to db
             @param album name as string
             @param album artist ids as [int]
             @param uri to an album track as string
             @param year as int
+            @param loved as bool
             @param popularity as int
+            @param rate as int
             @param mtime as int
             @param remote as bool
             @return (album id as int, new as bool)
@@ -395,8 +477,8 @@ class TagReader(Discoverer):
         album_id = Lp().albums.get_id(album_name, artist_ids, remote)
         if album_id is None:
             new = True
-            album_id = Lp().albums.add(album_name, artist_ids,
-                                       parent_uri, popularity, mtime)
+            album_id = Lp().albums.add(album_name, artist_ids, parent_uri,
+                                       loved, popularity, rate, mtime)
         # Now we have our album id, check if path doesn't change
         if Lp().albums.get_uri(album_id) != parent_uri:
             Lp().albums.set_uri(album_id, parent_uri)
