@@ -10,17 +10,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Gdk, GObject
+from gi.repository import Gtk, GLib, GObject
 
 from gettext import gettext as _
 
 from lollypop.view import LazyLoadingView
 from lollypop.widgets_album_simple import AlbumSimpleWidget
 from lollypop.pop_album import AlbumPopover
-from lollypop.pop_menu import AlbumMenu, AlbumMenuPopover
 from lollypop.view_artist_albums import ArtistAlbumsView
-from lollypop.objects import Album
-from lollypop.define import Type, ArtSize
+from lollypop.define import ArtSize
 
 
 class AlbumsView(LazyLoadingView):
@@ -46,7 +44,6 @@ class AlbumsView(LazyLoadingView):
         self._box.set_filter_func(self._filter_func)
         self._box.set_selection_mode(Gtk.SelectionMode.NONE)
         self._box.connect('child-activated', self.__on_album_activated)
-        self._box.connect('button-press-event', self.__on_button_press)
         # Allow lazy loading to not jump up and down
         self._box.set_homogeneous(True)
         self._box.set_max_children_per_line(1000)
@@ -128,37 +125,23 @@ class AlbumsView(LazyLoadingView):
             y = album_widget.translate_coordinates(self._box, 0, 0)[1]
             self._scrolled.get_allocation().height + y
             self._scrolled.get_vadjustment().set_value(y)
-        if self.__press_rect is not None:
-            album = Album(album_widget.id)
-            if self.__genre_ids and self.__genre_ids[0] == Type.CHARTS:
-                popover = AlbumMenuPopover(album, None)
-                popover.set_relative_to(cover)
-            elif album.is_web:
-                popover = AlbumMenuPopover(album, AlbumMenu(album, True))
-                popover.set_relative_to(cover)
-            else:
-                popover = Gtk.Popover.new_from_model(cover,
-                                                     AlbumMenu(album, True))
-            popover.set_position(Gtk.PositionType.BOTTOM)
-            popover.set_pointing_to(self.__press_rect)
+        allocation = self.get_allocation()
+        (x, top_height) = album_widget.translate_coordinates(self, 0, 0)
+        bottom_height = allocation.height -\
+            album_widget.get_allocation().height -\
+            top_height
+        if bottom_height > top_height:
+            height = bottom_height
         else:
-            allocation = self.get_allocation()
-            (x, top_height) = album_widget.translate_coordinates(self, 0, 0)
-            bottom_height = allocation.height -\
-                album_widget.get_allocation().height -\
-                top_height
-            if bottom_height > top_height:
-                height = bottom_height
-            else:
-                height = top_height
-            popover = AlbumPopover(album_widget.id,
-                                   self.__genre_ids,
-                                   self.__artist_ids,
-                                   allocation.width,
-                                   height,
-                                   ArtSize.NONE)
-            popover.set_relative_to(cover)
-            popover.set_position(Gtk.PositionType.BOTTOM)
+            height = top_height
+        popover = AlbumPopover(album_widget.id,
+                               self.__genre_ids,
+                               self.__artist_ids,
+                               allocation.width,
+                               height,
+                               ArtSize.NONE)
+        popover.set_relative_to(cover)
+        popover.set_position(Gtk.PositionType.BOTTOM)
         album_widget.show_overlay(False)
         album_widget.lock_overlay(True)
         popover.connect('closed', self.__on_album_popover_closed, album_widget)
@@ -175,21 +158,6 @@ class AlbumsView(LazyLoadingView):
         album_widget.lock_overlay(False)
         album_widget.get_cover().set_opacity(1)
 
-    def __on_button_press(self, flowbox, event):
-        """
-            Store pressed button
-            @param flowbox as Gtk.Flowbox
-            @param event as Gdk.EventButton
-        """
-        if event.button == 1:
-            self.__press_rect = None
-        else:
-            self.__press_rect = Gdk.Rectangle()
-            self.__press_rect.x = event.x
-            self.__press_rect.y = event.y
-            self.__press_rect.width = self.__press_rect.height = 1
-            event.button = 1
-
 
 class AlbumBackView(Gtk.Grid):
     """
