@@ -10,25 +10,29 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib
+from gi.repository import GObject, GLib
 
 from threading import Thread
 from time import time
 
 from lollypop.sqlcursor import SqlCursor
 from lollypop.tagreader import TagReader
-from lollypop.objects import Track, Album
 from lollypop.web_youtube import WebYouTube
 from lollypop.web_jgm90 import WebJmg90
 from lollypop.define import Lp, DbPersistent, Type
 from lollypop.lio import Lio
 
 
-class Web:
+class Web(GObject.Object):
     """
         Web helper
     """
 
+    __gsignals__ = {
+        'saved': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
+        'progress': (GObject.SignalFlags.RUN_FIRST, None, (float,))
+    }
+
     def play_track(track, play, callback):
         """
             Play track
@@ -48,6 +52,7 @@ class Web:
         """
             Init helper
         """
+        GObject.Object.__init__(self)
         self.__helpers = [WebJmg90(), WebYouTube()]
 
     def save_track(self, item, persistent):
@@ -66,9 +71,8 @@ class Web:
             @param item as SearchItem
             @param persistent as DbPersistent
         """
-        if persistent != DbPersistent.CHARTS:
-            Lp().window.progress.add(self)
-        t = Thread(target=self.__save_album_thread, args=(item, persistent))
+        t = Thread(target=self.__save_album_thread,
+                   args=(item, persistent))
         t.daemon = True
         t.start()
 
@@ -99,17 +103,12 @@ class Web:
                 t.daemon = True
                 t.start()
             start += 1
-            GLib.idle_add(Lp().window.progress.set_fraction,
-                          start / nb_items, self)
-        GLib.idle_add(Lp().window.progress.set_fraction, 1.0, self)
-        # Play if needed
-        if album_id is not None and persistent == DbPersistent.NONE:
-            Lp().player.clear_albums()
-            album = Album(album_id)
-            GLib.idle_add(Lp().player.load, album.tracks[0])
-            GLib.idle_add(Lp().player.add_album, album)
+            GLib.idle_add(self.emit, "progress", start / nb_items)
+        GLib.idle_add(self.emit, "progress", 1)
         if Lp().settings.get_value('artist-artwork'):
             Lp().art.cache_artists_info()
+        if album_id is not None:
+            GLib.idle_add(self.emit, "saved", album_id)
 
     def __save_track_thread(self, item, persistent):
         """
@@ -125,8 +124,7 @@ class Web:
         self.__save_cover(item, album_id)
         if Lp().settings.get_value('artist-artwork'):
             Lp().art.cache_artists_info()
-        if persistent == DbPersistent.NONE:
-            GLib.idle_add(Lp().player.load, Track(track_id))
+        GLib.idle_add(self.emit, "saved", track_id)
 
     def __save_track(self, item, persistent, album_artist):
         """
@@ -160,8 +158,8 @@ class Web:
             artist_ids = t.add_artists(artists, album_artist, "")
             album_artist_ids = t.add_album_artists(album_artist, "")
             (album_id, new_album) = t.add_album(item.album,
-                                                album_artist_ids,
-                                                "", 0, int(time()), True)
+                                                album_artist_ids, "",
+                                                False, 0, 0, int(time()), True)
             # FIXME: Check this, could move this in add_album()
             if new_album:
                 Lp().albums.set_synced(album_id, Type.NONE)
