@@ -75,8 +75,12 @@ class WebJmg90:
             artist = item.artists[0]
         unescaped = "%s %s" % (artist,
                                item.name)
+        for c in ['/', '?', '!']:
+            if c in unescaped:
+                unescaped = unescaped.replace(c, ' ')
+
         search = Lio.uri_escape_string(unescaped,
-                                       '/?',
+                                       '',
                                        True)
         try:
             # Strip /? as API doesn't like it
@@ -91,8 +95,8 @@ class WebJmg90:
                                             song['artists'][0]['name'].lower())
                         if song_artist == escape(artist.lower()):
                             return song['id']
-                    except:
-                        pass
+                    except Exception as e:
+                        print("WebJmg90::__get_jmg_id():", e)
         except IndexError:
             pass
         except KeyError:
