@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, GObject, Pango
+from gi.repository import Gtk, GLib, Gio, GObject, Pango
 
 from gettext import gettext as _
 from threading import Thread
@@ -18,8 +18,10 @@ from threading import Thread
 from lollypop.sync_mtp import MtpSync
 from lollypop.sqlcursor import SqlCursor
 from lollypop.cellrenderer import CellRendererAlbum
+from lollypop.selectionlist import SelectionList
 from lollypop.define import Lp, Type
 from lollypop.objects import Album
+from lollypop.loader import Loader
 from lollypop.lio import Lio
 
 
@@ -47,6 +49,7 @@ class DeviceManagerWidget(Gtk.Bin, MtpSync):
 
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/DeviceManagerWidget.ui')
+        widget = builder.get_object('widget')
         self.__error_label = builder.get_object('error-label')
         self.__switch_albums = builder.get_object('switch_albums')
         self.__switch_albums.set_state(Lp().settings.get_value('sync-albums'))
@@ -63,22 +66,26 @@ class DeviceManagerWidget(Gtk.Bin, MtpSync):
         self.__menu = builder.get_object('menu')
 
         self.__model = Gtk.ListStore(bool, str, int)
-        self.__model.set_sort_column_id(1, Gtk.SortType.ASCENDING)
-        self.__model.set_sort_func(1, self.__sort_items)
+
+        self.__selection_list = SelectionList(False)
+        self.__selection_list.connect('item-selected',
+                                      self.__on_item_selected)
+        widget.attach(self.__selection_list, 1, 1, 1, 1)
+        self.__selection_list.set_hexpand(True)
 
         self.__view = builder.get_object('view')
         self.__view.set_model(self.__model)
 
         builder.connect_signals(self)
 
-        self.add(builder.get_object('widget'))
+        self.add(widget)
 
         self.__infobar = builder.get_object('infobar')
         self.__infobar_label = builder.get_object('infobarlabel')
 
         renderer0 = Gtk.CellRendererToggle()
         renderer0.set_property('activatable', True)
-        renderer0.connect('toggled', self.__on_playlist_toggled)
+        renderer0.connect('toggled', self.__on_item_toggled)
         column0 = Gtk.TreeViewColumn(" ✓", renderer0, active=0)
         column0.set_clickable(True)
         column0.connect('clicked', self.__on_column0_clicked)
@@ -104,17 +111,19 @@ class DeviceManagerWidget(Gtk.Bin, MtpSync):
         self.__model.clear()
         self.__stop = False
         if Lp().settings.get_value('sync-albums'):
-            albums = Lp().albums.get_ids()
-            albums += Lp().albums.get_compilation_ids()
-            self.__append_albums(albums)
+            self.__selection_list.clear()
+            self.__setup_list_artists(self.__selection_list)
             self.__column1.set_visible(True)
             self.__column2.set_title(_("Albums"))
+            self.__selection_list.show()
+            self.__selection_list.select_ids([Type.ALL])
         else:
             playlists = [(Type.LOVED, Lp().playlists.LOVED)]
             playlists += Lp().playlists.get()
             self.__append_playlists(playlists)
             self.__column1.set_visible(False)
             self.__column2.set_title(_("Playlists"))
+            self.__selection_list.hide()
 
     def set_uri(self, uri):
         """
@@ -282,27 +291,53 @@ class DeviceManagerWidget(Gtk.Bin, MtpSync):
 #######################
 # PRIVATE             #
 #######################
-    def __sort_items(self, model, itera, iterb, data):
+    def __setup_list_artists(self, selection_list):
         """
-            Sort model
+            Setup list for artists
+            @param list as SelectionList
+            @thread safe
         """
-        a = model.get_value(itera, 1)
-        b = model.get_value(iterb, 1)
-        return a.lower() > b.lower()
+        def load():
+            artists = Lp().artists.get_local()
+            compilations = Lp().albums.get_compilation_ids()
+            return (artists, compilations)
 
-    def __append_playlists(self, playlists):
+        def setup(artists, compilations):
+            items = []
+            items.append((Type.ALL, _("Synced albums")))
+            if compilations:
+                items.append((Type.COMPILATIONS, _("Compilations")))
+                items.append((Type.SEPARATOR, ''))
+            items += artists
+            selection_list.mark_as_artists(True)
+            selection_list.populate(items)
+        loader = Loader(target=load, view=selection_list,
+                        on_finished=lambda r: setup(*r))
+        loader.start()
+
+    def __append_playlists(self, playlists, files_list=[]):
         """
             Append a playlist
             @param playlists as [(int, str)]
+            @internal files_list
         """
         if playlists and not self.__stop:
+            # Cache directory playlists
+            if not files_list:
+                d = Lio.File.new_for_uri(self._uri)
+                infos = d.enumerate_children('standard::name,standard::type',
+                                             Gio.FileQueryInfoFlags.NONE,
+                                             None)
+                for info in infos:
+                    if info.get_file_type() != Gio.FileType.DIRECTORY:
+                        f = infos.get_child(info)
+                        if f.get_uri().endswith(".m3u"):
+                            files_list.append(
+                                          GLib.path_get_basename(f.get_path()))
             playlist = playlists.pop(0)
-            playlist_name = GLib.uri_escape_string(playlist[1], "", False)
-            playlist_obj = Lio.File.new_for_uri(self._uri + "/" +
-                                                playlist_name + '.m3u')
-            selected = playlist_obj.query_exists()
+            selected = playlist[1] + ".m3u" in files_list
             self.__model.append([selected, playlist[1], playlist[0]])
-            GLib.idle_add(self.__append_playlists, playlists)
+            GLib.idle_add(self.__append_playlists, playlists, files_list)
 
     def __append_albums(self, albums):
         """
@@ -334,6 +369,22 @@ class DeviceManagerWidget(Gtk.Bin, MtpSync):
         if Lp().settings.get_value('sync-albums'):
             Lp().albums.set_synced(album_id, toggle)
 
+    def __on_item_selected(self, selection_list):
+        """
+            Show album from artist
+            @param selection list as SelectionList
+        """
+        if not selection_list.selected_ids:
+            return
+        if selection_list.selected_ids[0] == Type.COMPILATIONS:
+            albums = Lp().albums.get_compilation_ids()
+        elif selection_list.selected_ids[0] == Type.ALL:
+            albums = Lp().albums.get_synced_ids()
+        else:
+            albums = Lp().albums.get_ids(selection_list.selected_ids)
+        self.__model.clear()
+        self.__append_albums(albums)
+
     def __on_column0_clicked(self, column):
         """
             Select/Unselect all playlists
@@ -349,7 +400,7 @@ class DeviceManagerWidget(Gtk.Bin, MtpSync):
         with SqlCursor(Lp().db) as sql:
             sql.commit()
 
-    def __on_playlist_toggled(self, view, path):
+    def __on_item_toggled(self, view, path):
         """
             When item is toggled, set model
             @param widget as cell renderer
