@@ -15,6 +15,7 @@ from gi.repository import GObject, Gtk, Gdk, Pango, GLib, Gst
 from lollypop.define import Lp, ArtSize, Type
 from lollypop.pop_menu import TrackMenuPopover, TrackMenu
 from lollypop.widgets_indicator import IndicatorWidget
+from lollypop.widgets_context import ContextWidget
 from lollypop.utils import seconds_to_string
 from lollypop.objects import Track
 from lollypop import utils
@@ -36,13 +37,16 @@ class Row(Gtk.ListBoxRow):
         self._artists_label = None
         self._track = Track(rowid)
         self.__number = num
-        self.__timeout_id = None
+        self.__preview_timeout_id = None
+        self.__context_timeout_id = None
+        self.__context = None
         self._indicator = IndicatorWidget(self._track.id)
         self.set_indicator(Lp().player.current_track.id == self._track.id,
                            utils.is_loved(self._track.id))
         self._row_widget = Gtk.EventBox()
         self._row_widget.connect('button-press-event', self.__on_button_press)
         self._row_widget.connect('enter-notify-event', self.__on_enter_notify)
+        self._row_widget.connect('leave-notify-event', self.__on_leave_notify)
         self._grid = Gtk.Grid()
         self._grid.set_column_spacing(5)
         self._row_widget.add(self._grid)
@@ -120,7 +124,7 @@ class Row(Gtk.ListBoxRow):
         else:
             self.get_style_context().remove_class('trackrowplaying')
             self.get_style_context().add_class('trackrow')
-            if loved:
+            if loved and self.__context is None:
                 self._indicator.loved()
             else:
                 self._indicator.empty()
@@ -144,7 +148,7 @@ class Row(Gtk.ListBoxRow):
         """
             Update position label for row
         """
-        if Lp().player.is_in_queue(self._track.id):
+        if Lp().player.track_in_queue(self._track):
             self._num_label.get_style_context().add_class('queued')
             pos = Lp().player.get_track_position(self._track.id)
             self._num_label.set_text(str(pos))
@@ -174,7 +178,7 @@ class Row(Gtk.ListBoxRow):
         Lp().player.preview.set_property('uri', self._track.uri)
         Lp().player.preview.set_state(Gst.State.PLAYING)
         self.set_indicator(True, False)
-        self.__timeout_id = None
+        self.__preview_timeout_id = None
 
     def __on_map(self, widget):
         """
@@ -196,11 +200,14 @@ class Row(Gtk.ListBoxRow):
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
+        if self.__context_timeout_id is not None:
+            GLib.source_remove(self.__context_timeout_id)
+            self.__context_timeout_id = None
         if Lp().settings.get_value('preview-output').get_string() != '':
-            widget.connect('leave-notify-event', self.__on_leave_notify)
-            self.__timeout_id = GLib.timeout_add(500, self.__play_preview)
+            self.__preview_timeout_id = GLib.timeout_add(500,
+                                                         self.__play_preview)
         if self.__menu_button.get_image() is None:
-            image = Gtk.Image.new_from_icon_name('open-menu-symbolic',
+            image = Gtk.Image.new_from_icon_name('go-previous-symbolic',
                                                  Gtk.IconSize.MENU)
             image.set_opacity(0.2)
             self.__menu_button.set_image(image)
@@ -213,13 +220,25 @@ class Row(Gtk.ListBoxRow):
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
-        if self.__timeout_id is not None:
-            GLib.source_remove(self.__timeout_id)
-            self.__timeout_id = None
-        self.set_indicator(Lp().player.current_track.id == self._track.id,
-                           utils.is_loved(self._track.id))
-        Lp().player.preview.set_state(Gst.State.NULL)
-        widget.disconnect_by_func(self.__on_leave_notify)
+        allocation = widget.get_allocation()
+        if event.x <= 0 or\
+           event.x >= allocation.width or\
+           event.y <= 0 or\
+           event.y >= allocation.height:
+            if self.__context is not None and\
+                    self.__context_timeout_id is None:
+                self.__context_timeout_id = GLib.timeout_add(
+                                                      1000,
+                                                      self.__on_button_clicked,
+                                                      self.__menu_button)
+            if Lp().settings.get_value('preview-output').get_string() != '':
+                if self.__preview_timeout_id is not None:
+                    GLib.source_remove(self.__preview_timeout_id)
+                    self.__preview_timeout_id = None
+                self.set_indicator(
+                                Lp().player.current_track.id == self._track.id,
+                                utils.is_loved(self._track.id))
+                Lp().player.preview.set_state(Gst.State.NULL)
 
     def __on_button_press(self, widget, event):
         """
@@ -227,13 +246,18 @@ class Row(Gtk.ListBoxRow):
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
-        if event.button == 3 and Gtk.get_minor_version() > 16:
+        if self.__context is not None:
+            self.__on_button_clicked(self.__menu_button)
+        if event.button == 3:
+            if GLib.getenv("WAYLAND_DISPLAY") != "" and\
+                    self.get_ancestor(Gtk.Popover) is not None:
+                print("https://bugzilla.gnome.org/show_bug.cgi?id=774148")
             window = widget.get_window()
             if window == event.window:
                 self.__popup_menu(widget, event.x, event.y)
             # Happens when pressing button over menu btn
             else:
-                self.__popup_menu(self.__menu_button)
+                self.__on_button_clicked(self.__menu_button)
             return True
         elif event.button == 2:
             if self._track.id in Lp().player.get_queue():
@@ -241,12 +265,33 @@ class Row(Gtk.ListBoxRow):
             else:
                 Lp().player.append_to_queue(self._track.id)
 
-    def __on_button_clicked(self, widget):
+    def __on_button_clicked(self, button):
         """
             Popup menu for track relative to button
-            @param widget as Gtk.Button
+            @param button as Gtk.Button
         """
-        self.__popup_menu(widget)
+        self.__context_timeout_id = None
+        image = self.__menu_button.get_image()
+        if self.__context is None:
+            image.set_from_icon_name('go-next-symbolic',
+                                     Gtk.IconSize.MENU)
+            self.__context = ContextWidget(self._track, button)
+            self.__context.set_property('halign', Gtk.Align.END)
+            self.__context.show()
+            self._duration_label.hide()
+            self._grid.insert_next_to(button, Gtk.PositionType.LEFT)
+            self._grid.attach_next_to(self.__context, button,
+                                      Gtk.PositionType.LEFT, 1, 1)
+            self.set_indicator(Lp().player.current_track.id == self._track.id,
+                               False)
+        else:
+            image.set_from_icon_name('go-previous-symbolic',
+                                     Gtk.IconSize.MENU)
+            self.__context.destroy()
+            self._duration_label.show()
+            self.__context = None
+            self.set_indicator(Lp().player.current_track.id == self._track.id,
+                               utils.is_loved(self._track.id))
 
     def __popup_menu(self, widget, xcoordinate=None, ycoordinate=None):
         """
@@ -256,13 +301,13 @@ class Row(Gtk.ListBoxRow):
             @param ycoordinate as int (or None)
         """
         popover = TrackMenuPopover(self._track, TrackMenu(self._track))
-        popover.set_relative_to(widget)
         if xcoordinate is not None and ycoordinate is not None:
             rect = widget.get_allocation()
             rect.x = xcoordinate
             rect.y = ycoordinate
             rect.width = rect.height = 1
-            popover.set_pointing_to(rect)
+        popover.set_relative_to(widget)
+        popover.set_pointing_to(rect)
         popover.connect('closed', self.__on_closed)
         self.get_style_context().add_class('track-menu-selected')
         popover.show()
@@ -320,8 +365,8 @@ class PlaylistRow(Row):
         self.__cover = Gtk.Image()
         self.__cover.set_property('halign', Gtk.Align.CENTER)
         self.__cover.set_property('valign', Gtk.Align.CENTER)
-        if self._track.is_youtube:
-            self.__cover.get_style_context().add_class('small-cover-youtube')
+        if self._track.is_web:
+            self.__cover.get_style_context().add_class('small-cover-web')
         else:
             self.__cover.get_style_context().add_class('small-cover-frame')
         self.__cover.set_no_show_all(True)
@@ -455,18 +500,20 @@ class PlaylistRow(Row):
             @param info as int
             @param time as int
         """
+        height = self.get_allocated_height()
+        if y > height/2:
+            up = False
+        else:
+            up = True
         try:
             src = int(data.get_text())
             if self._track.id == src:
                 return
-            height = self.get_allocated_height()
-            if y > height/2:
-                up = False
-            else:
-                up = True
             self.emit('track-moved', self._track.id, src, up)
         except:
-            pass
+            if len(Lp().window.view.get_ids()) == 1:
+                Lp().playlists.import_uri(Lp().window.view.get_ids()[0],
+                                          data.get_text(), self._track.id, up)
 
     def __on_drag_motion(self, widget, context, x, y, time):
         """
@@ -653,11 +700,13 @@ class TracksWidget(Gtk.ListBox):
             @param time as int
         """
         try:
+            value = int(data.get_text())
             bottom_row = self.get_children()[-1]
-            bottom_row.emit('track-moved', bottom_row.id,
-                            int(data.get_text()), False)
+            bottom_row.emit('track-moved', bottom_row.id, value, False)
         except:
-            pass
+            if len(Lp().window.view.get_ids()) == 1:
+                Lp().playlists.import_uri(Lp().window.view.get_ids()[0],
+                                          data.get_text())
 
     def __on_queue_changed(self, unused):
         """
@@ -666,12 +715,14 @@ class TracksWidget(Gtk.ListBox):
         for row in self.get_children():
             row.update_num_label()
 
-    def __on_loved_playlist_changed(self, widget, playlist_id, track_id):
+    def __on_loved_playlist_changed(self, widget, playlist_id,
+                                    track_id, pos=None):
         """
             Updates the loved icon
             @param playlist as Playlist
             @param playlist id as int
             @param track id as int
+            @param pos as unused
         """
         if playlist_id != Type.LOVED:
             return
